@@ -20,11 +20,14 @@
  */
 
 #include <dirent.h>
+#include <pthread.h>
+#include <string.h>
 #include <sys/stat.h>
 
 #include <gtk/gtk.h>
 
 #include <libaudcore/audstrings.h>
+#include <libaudcore/hook.h>
 
 #include "config.h"
 #include "i18n.h"
@@ -35,33 +38,36 @@
 #include "misc.h"
 
 typedef struct {
-    gint playlist_id, at;
-    gboolean play;
-    struct index * filenames, * tuples;
+    int playlist_id, at;
+    bool_t play;
+    Index * filenames, * tuples;
+    PlaylistFilterFunc filter;
+    void * user;
 } AddTask;
 
 typedef struct {
-    gint playlist_id, at;
-    gboolean play;
-    struct index * filenames, * tuples, * decoders;
+    int playlist_id, at;
+    bool_t play;
+    Index * filenames, * tuples, * decoders;
 } AddResult;
 
 static GList * add_tasks = NULL;
 static GList * add_results = NULL;
+static int current_playlist_id = -1;
 
-static GMutex * mutex;
-static GCond * cond;
-static gboolean add_quit;
-static GThread * add_thread;
-static gint add_source = 0;
+static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
+static bool_t add_quit;
+static pthread_t add_thread;
+static int add_source = 0;
 
-static gint status_source = 0;
-static gchar status_path[512];
-static gint status_count;
+static int status_source = 0;
+static char status_path[512];
+static int status_count;
 static GtkWidget * status_window = NULL, * status_path_label,
  * status_count_label;
 
-static gboolean status_cb (void * unused)
+static bool_t status_cb (void * unused)
 {
     if (! headless && ! status_window)
     {
@@ -101,9 +107,9 @@ static gboolean status_cb (void * unused)
          gtk_widget_destroyed, & status_window);
     }
 
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
 
-    gchar scratch[128];
+    char scratch[128];
     snprintf (scratch, sizeof scratch, dngettext (PACKAGE, "%d file found",
      "%d files found", status_count), status_count);
 
@@ -118,13 +124,13 @@ static gboolean status_cb (void * unused)
         gtk_label_set_text ((GtkLabel *) status_count_label, scratch);
     }
 
-    g_mutex_unlock (mutex);
+    pthread_mutex_unlock (& mutex);
     return TRUE;
 }
 
-static void status_update (const gchar * filename, gint found)
+static void status_update (const char * filename, int found)
 {
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
 
     snprintf (status_path, sizeof status_path, "%s", filename);
     status_count = found;
@@ -132,7 +138,7 @@ static void status_update (const gchar * filename, gint found)
     if (! status_source)
         status_source = g_timeout_add (250, status_cb, NULL);
 
-    g_mutex_unlock (mutex);
+    pthread_mutex_unlock (& mutex);
 }
 
 static void status_done_locked (void)
@@ -149,41 +155,40 @@ static void status_done_locked (void)
         gtk_widget_destroy (status_window);
 }
 
-static void index_free_filenames (struct index * filenames)
+static void index_free_filenames (Index * filenames)
 {
-    gint count = index_count (filenames);
-    for (gint i = 0; i < count; i ++)
-    {
-        gchar * filename = index_get (filenames, i);
-        if (filename)
-            g_free (filename);
-    }
+    int count = index_count (filenames);
+    for (int i = 0; i < count; i ++)
+        str_unref (index_get (filenames, i));
 
     index_free (filenames);
 }
 
-static void index_free_tuples (struct index * tuples)
+static void index_free_tuples (Index * tuples)
 {
-    gint count = index_count (tuples);
-    for (gint i = 0; i < count; i ++)
+    int count = index_count (tuples);
+    for (int i = 0; i < count; i ++)
     {
         Tuple * tuple = index_get (tuples, i);
         if (tuple)
-            tuple_free (tuple);
+            tuple_unref (tuple);
     }
 
     index_free (tuples);
 }
 
-static AddTask * add_task_new (gint playlist_id, gint at, gboolean play,
- struct index * filenames, struct index * tuples)
+static AddTask * add_task_new (int playlist_id, int at, bool_t play,
+ Index * filenames, Index * tuples, PlaylistFilterFunc filter,
+ void * user)
 {
-    AddTask * task = g_malloc (sizeof (AddTask));
+    AddTask * task = g_slice_new (AddTask);
     task->playlist_id = playlist_id;
     task->at = at;
     task->play = play;
     task->filenames = filenames;
     task->tuples = tuples;
+    task->filter = filter;
+    task->user = user;
     return task;
 }
 
@@ -194,12 +199,12 @@ static void add_task_free (AddTask * task)
     if (task->tuples)
         index_free_tuples (task->tuples);
 
-    g_free (task);
+    g_slice_free (AddTask, task);
 }
 
-static AddResult * add_result_new (gint playlist_id, gint at, gboolean play)
+static AddResult * add_result_new (int playlist_id, int at, bool_t play)
 {
-    AddResult * result = g_malloc (sizeof (AddResult));
+    AddResult * result = g_slice_new (AddResult);
     result->playlist_id = playlist_id;
     result->at = at;
     result->play = play;
@@ -218,21 +223,27 @@ static void add_result_free (AddResult * result)
     if (result->decoders)
         index_free (result->decoders);
 
-    g_free (result);
+    g_slice_free (AddResult, result);
 }
 
-static void add_file (gchar * filename, Tuple * tuple, PluginHandle * decoder,
- AddResult * result, gboolean filter)
+static void add_file (char * filename, Tuple * tuple, PluginHandle * decoder,
+ PlaylistFilterFunc filter, void * user, AddResult * result, bool_t validate)
 {
     g_return_if_fail (filename);
+    if (filter && ! filter (filename, user))
+    {
+        str_unref (filename);
+        return;
+    }
+
     status_update (filename, index_count (result->filenames));
 
     if (! tuple && ! decoder)
     {
         decoder = file_find_decoder (filename, TRUE);
-        if (filter && ! decoder)
+        if (validate && ! decoder)
         {
-            g_free (filename);
+            str_unref (filename);
             return;
         }
     }
@@ -241,17 +252,19 @@ static void add_file (gchar * filename, Tuple * tuple, PluginHandle * decoder,
      (filename, '?'))
         tuple = file_read_tuple (filename, decoder);
 
-    if (tuple && tuple->nsubtunes > 0)
+    int n_subtunes = tuple ? tuple_get_n_subtunes (tuple) : 0;
+
+    if (n_subtunes)
     {
-        for (gint sub = 0; sub < tuple->nsubtunes; sub ++)
+        for (int sub = 0; sub < n_subtunes; sub ++)
         {
-            gchar * subname = g_strdup_printf ("%s?%d", filename, tuple->subtunes ?
-             tuple->subtunes[sub] : 1 + sub);
-            add_file (subname, NULL, decoder, result, FALSE);
+            char * subname = str_printf ("%s?%d", filename,
+             tuple_get_nth_subtune (tuple, sub));
+            add_file (subname, NULL, decoder, filter, user, result, FALSE);
         }
 
-        g_free (filename);
-        tuple_free (tuple);
+        str_unref (filename);
+        tuple_unref (tuple);
         return;
     }
 
@@ -260,13 +273,25 @@ static void add_file (gchar * filename, Tuple * tuple, PluginHandle * decoder,
     index_append (result->decoders, decoder);
 }
 
-static void add_folder (gchar * filename, AddResult * result)
+static void add_folder (char * filename, PlaylistFilterFunc filter,
+ void * user, AddResult * result)
 {
     g_return_if_fail (filename);
+    if (filter && ! filter (filename, user))
+    {
+        str_unref (filename);
+        return;
+    }
+
     status_update (filename, index_count (result->filenames));
 
-    gchar * unix_name = uri_to_filename (filename);
-    g_return_if_fail (unix_name);
+    char * unix_name = uri_to_filename (filename);
+    if (! unix_name)
+    {
+        str_unref (filename);
+        return;
+    }
+
     if (unix_name[strlen (unix_name) - 1] == '/')
         unix_name[strlen (unix_name) - 1] = 0;
 
@@ -294,13 +319,21 @@ static void add_folder (gchar * filename, AddResult * result)
 
         if (S_ISREG (info.st_mode))
         {
-            gchar * item_name = filename_to_uri (files->data);
-            add_file (item_name, NULL, NULL, result, TRUE);
+            char * item_name = filename_to_uri (files->data);
+            if (item_name)
+            {
+                add_file (str_get (item_name), NULL, NULL, filter, user, result, TRUE);
+                g_free (item_name);
+            }
         }
         else if (S_ISDIR (info.st_mode))
         {
-            gchar * item_name = filename_to_uri (files->data);
-            add_folder (item_name, result);
+            char * item_name = filename_to_uri (files->data);
+            if (item_name)
+            {
+                add_folder (str_get (item_name), filter, user, result);
+                g_free (item_name);
+            }
         }
 
     NEXT:
@@ -309,64 +342,71 @@ static void add_folder (gchar * filename, AddResult * result)
     }
 
 FREE:
-    g_free (filename);
+    str_unref (filename);
     g_free (unix_name);
 }
 
-static void add_playlist (gchar * filename, AddResult * result)
+static void add_playlist (char * filename, PlaylistFilterFunc filter,
+ void * user, AddResult * result)
 {
     g_return_if_fail (filename);
-    status_update (filename, index_count (result->filenames));
-
-    gchar * title = NULL;
-    struct index * filenames, * tuples;
-    if (! playlist_load (filename, & title, & filenames, & tuples))
+    if (filter && ! filter (filename, user))
     {
-        g_free (filename);
+        str_unref (filename);
         return;
     }
 
-    gint count = index_count (filenames);
-    for (gint i = 0; i < count; i ++)
-        add_file (index_get (filenames, i), tuples ? index_get (tuples, i) :
-         NULL, NULL, result, FALSE);
+    status_update (filename, index_count (result->filenames));
 
-    g_free (filename);
-    g_free (title);
+    char * title = NULL;
+    Index * filenames, * tuples;
+    if (! playlist_load (filename, & title, & filenames, & tuples))
+    {
+        str_unref (filename);
+        return;
+    }
+
+    int count = index_count (filenames);
+    for (int i = 0; i < count; i ++)
+        add_file (index_get (filenames, i), tuples ? index_get (tuples, i) :
+         NULL, NULL, filter, user, result, FALSE);
+
+    str_unref (filename);
+    str_unref (title);
     index_free (filenames);
     if (tuples)
         index_free (tuples);
 }
 
-static void add_generic (gchar * filename, Tuple * tuple, AddResult * result,
- gboolean filter)
+static void add_generic (char * filename, Tuple * tuple,
+ PlaylistFilterFunc filter, void * user, AddResult * result)
 {
     g_return_if_fail (filename);
 
     if (tuple)
-        add_file (filename, tuple, NULL, result, filter);
+        add_file (filename, tuple, NULL, filter, user, result, FALSE);
     else if (vfs_file_test (filename, G_FILE_TEST_IS_DIR))
-        add_folder (filename, result);
+        add_folder (filename, filter, user, result);
     else if (filename_is_playlist (filename))
-        add_playlist (filename, result);
+        add_playlist (filename, filter, user, result);
     else
-        add_file (filename, NULL, NULL, result, filter);
+        add_file (filename, NULL, NULL, filter, user, result, FALSE);
 }
 
-static gboolean add_finish (void * unused)
+static bool_t add_finish (void * unused)
 {
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
 
     while (add_results)
     {
         AddResult * result = add_results->data;
         add_results = g_list_delete_link (add_results, add_results);
 
-        gint playlist = playlist_by_unique_id (result->playlist_id);
+        int playlist = playlist_by_unique_id (result->playlist_id);
         if (playlist < 0) /* playlist deleted */
             goto FREE;
 
-        gint count = playlist_entry_count (playlist);
+        int count = playlist_entry_count (playlist);
         if (result->at < 0 || result->at > count)
             result->at = count;
 
@@ -398,39 +438,43 @@ static gboolean add_finish (void * unused)
     if (! add_tasks)
         status_done_locked ();
 
-    g_mutex_unlock (mutex);
+    pthread_mutex_unlock (& mutex);
+
+    hook_call ("playlist add complete", NULL);
     return FALSE;
 }
 
 static void * add_worker (void * unused)
 {
-    g_mutex_lock (mutex);
-    g_cond_broadcast (cond);
+    pthread_mutex_lock (& mutex);
 
     while (! add_quit)
     {
         if (! add_tasks)
         {
-            g_cond_wait (cond, mutex);
+            pthread_cond_wait (& cond, & mutex);
             continue;
         }
 
         AddTask * task = add_tasks->data;
         add_tasks = g_list_delete_link (add_tasks, add_tasks);
 
-        g_mutex_unlock (mutex);
+        current_playlist_id = task->playlist_id;
+        pthread_mutex_unlock (& mutex);
 
         AddResult * result = add_result_new (task->playlist_id, task->at,
          task->play);
 
-        gint count = index_count (task->filenames);
+        int count = index_count (task->filenames);
         if (task->tuples)
             count = MIN (count, index_count (task->tuples));
 
-        for (gint i = 0; i < count; i ++)
+        for (int i = 0; i < count; i ++)
         {
             add_generic (index_get (task->filenames, i), task->tuples ?
-             index_get (task->tuples, i) : NULL, result, FALSE);
+             index_get (task->tuples, i) : NULL, task->filter, task->user,
+             result);
+
             index_set (task->filenames, i, NULL);
             if (task->tuples)
                 index_set (task->tuples, i, NULL);
@@ -438,7 +482,8 @@ static void * add_worker (void * unused)
 
         add_task_free (task);
 
-        g_mutex_lock (mutex);
+        pthread_mutex_lock (& mutex);
+        current_playlist_id = -1;
 
         add_results = g_list_append (add_results, result);
 
@@ -446,30 +491,25 @@ static void * add_worker (void * unused)
             add_source = g_timeout_add (0, add_finish, NULL);
     }
 
-    g_mutex_unlock (mutex);
+    pthread_mutex_unlock (& mutex);
     return NULL;
 }
 
 void adder_init (void)
 {
-    mutex = g_mutex_new ();
-    cond = g_cond_new ();
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
     add_quit = FALSE;
-    add_thread = g_thread_create (add_worker, NULL, TRUE, NULL);
-    g_cond_wait (cond, mutex);
-    g_mutex_unlock (mutex);
+    pthread_create (& add_thread, NULL, add_worker, NULL);
+    pthread_mutex_unlock (& mutex);
 }
 
 void adder_cleanup (void)
 {
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
     add_quit = TRUE;
-    g_cond_broadcast (cond);
-    g_mutex_unlock (mutex);
-    g_thread_join (add_thread);
-    g_mutex_free (mutex);
-    g_cond_free (cond);
+    pthread_cond_broadcast (& cond);
+    pthread_mutex_unlock (& mutex);
+    pthread_join (add_thread, NULL);
 
     if (add_source)
     {
@@ -480,27 +520,64 @@ void adder_cleanup (void)
     status_done_locked ();
 }
 
-void playlist_entry_insert (gint playlist, gint at, gchar * filename,
- Tuple * tuple, gboolean play)
+void playlist_entry_insert (int playlist, int at, const char * filename,
+ Tuple * tuple, bool_t play)
 {
-    struct index * filenames = index_new ();
-    struct index * tuples = index_new ();
-    index_append (filenames, filename);
+    Index * filenames = index_new ();
+    Index * tuples = index_new ();
+    index_append (filenames, str_get (filename));
     index_append (tuples, tuple);
 
     playlist_entry_insert_batch (playlist, at, filenames, tuples, play);
 }
 
-void playlist_entry_insert_batch (gint playlist, gint at,
- struct index * filenames, struct index * tuples, gboolean play)
+void playlist_entry_insert_batch (int playlist, int at,
+ Index * filenames, Index * tuples, bool_t play)
 {
-    gint playlist_id = playlist_get_unique_id (playlist);
+    playlist_entry_insert_filtered (playlist, at, filenames, tuples, NULL, NULL, play);
+}
+
+void playlist_entry_insert_filtered (int playlist, int at,
+ Index * filenames, Index * tuples, PlaylistFilterFunc filter,
+ void * user, bool_t play)
+{
+    int playlist_id = playlist_get_unique_id (playlist);
     g_return_if_fail (playlist_id >= 0);
 
-    AddTask * task = add_task_new (playlist_id, at, play, filenames, tuples);
+    AddTask * task = add_task_new (playlist_id, at, play, filenames, tuples, filter, user);
 
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
     add_tasks = g_list_append (add_tasks, task);
-    g_cond_broadcast (cond);
-    g_mutex_unlock (mutex);
+    pthread_cond_broadcast (& cond);
+    pthread_mutex_unlock (& mutex);
+}
+
+bool_t playlist_add_in_progress (int playlist)
+{
+    int playlist_id = playlist_get_unique_id (playlist);
+    g_return_val_if_fail (playlist_id >= 0, FALSE);
+
+    pthread_mutex_lock (& mutex);
+
+    for (GList * node = add_tasks; node; node = node->next)
+    {
+        if (((AddTask *) node->data)->playlist_id == playlist_id)
+            goto YES;
+    }
+
+    if (current_playlist_id == playlist_id)
+        goto YES;
+
+    for (GList * node = add_results; node; node = node->next)
+    {
+        if (((AddResult *) node->data)->playlist_id == playlist_id)
+            goto YES;
+    }
+
+    pthread_mutex_unlock (& mutex);
+    return FALSE;
+
+YES:
+    pthread_mutex_unlock (& mutex);
+    return TRUE;
 }
