@@ -194,6 +194,7 @@ static const char * const translators_text[] = {
     N_("Brazilian Portuguese:"),
     "Fábio Antunes",
     "Karen Eliot",
+    "Rafael Ferreira",
     "Philipi Pinto",
     NULL,
     N_("Breton:"),
@@ -218,6 +219,7 @@ static const char * const translators_text[] = {
     NULL,
     N_("Dutch:"),
     "Laurens Buhler",
+    "Bjorn Roesbeke",
     "Tony Vroon",
     NULL,
     N_("Estonian:"),
@@ -230,10 +232,11 @@ static const char * const translators_text[] = {
     "Pauli Virtanen",
     NULL,
     N_("French:"),
+    "Alain-Olivier Breysse",
     "Adam Cecile",
-    "Stanislas Zeller",
-    "Stany Henry",
     "Jean-Alexandre Anglès d'Auriac",
+    "Stany Henry",
+    "Stanislas Zeller",
     NULL,
     N_("German:"),
     "Matthias Debus",
@@ -290,6 +293,7 @@ static const char * const translators_text[] = {
     "Szymon Weihs",
     NULL,
     N_("Portuguese:"),
+    "Sérgio Marques",
     "Luís Picciochi Oliveira",
     NULL,
     N_("Romanian:"),
@@ -337,6 +341,7 @@ static const char * const translators_text[] = {
     "Eren Turkay",
     NULL,
     N_("Ukrainian:"),
+    "Yuri Chornoivan",
     "Kostyantyn Fedenko",
     "Rax Garfield",
     "Mykola Lynnyk",
